==> jc-1.4.0.tar.gz: javax/swing/text/JTextComponent__24KeymapWrapper.h <==
// class javax.swing.text.JTextComponent$KeymapWrapper

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 790c4e1b642750d1 javax_swing_InputMap
// @dep_class 9c12f8e28e5102dd javax_swing_text_JTextComponent__24KeymapWrapper

// header file dependencies
// @dep_header javax_swing_InputMap

#include "javax/swing/InputMap.h"

#ifndef _JC_javax_swing_text_JTextComponent__24KeymapWrapper_H_
#define _JC_javax_swing_text_JTextComponent__24KeymapWrapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_KeyStroke$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_Keymap$object;

// Typedefs
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_refs	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_nonrefs	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$refs	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$nonrefs	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$object;

typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vmethods	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vmethods;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtable	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtable;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtype	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtype;

// Constructors
extern void _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method$_init$7c9889f92e4657d3(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_object *);

// Virtual methods
extern _jc_object_array *_jc_javax_swing_text_JTextComponent__24KeymapWrapper$method$allKeys$fca17f47510e13bb(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *);
extern struct _jc_java_lang_Object$object *_jc_javax_swing_text_JTextComponent__24KeymapWrapper$method$get$191a2e1929297667(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *, struct _jc_javax_swing_KeyStroke$object *);
extern _jc_object_array *_jc_javax_swing_text_JTextComponent__24KeymapWrapper$method$keys$aa8bd082cd0ed021(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *);
extern jint _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method$size$345df5220fc60ade(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method_info$allKeys$fca17f47510e13bb;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method_info$get$191a2e1929297667;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method_info$keys$aa8bd082cd0ed021;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vmethods {
	_jc_object_array	*(*allKeys$fca17f47510e13bb)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *);
	struct _jc_java_lang_Object$object	*(*get$191a2e1929297667)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *, struct _jc_javax_swing_KeyStroke$object *);
	_jc_object_array	*(*keys$aa8bd082cd0ed021)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *);
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *);
};

// Vtable
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_InputMap$vmethods	javax_swing_InputMap;
	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vmethods	javax_swing_text_JTextComponent__24KeymapWrapper;
};

// Vtype
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtype {
	_jc_type			type;
	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_refs {
	struct _jc_object	*map;
	struct _jc_javax_swing_text_JTextComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$refs {
    _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_refs	javax_swing_text_JTextComponent__24KeymapWrapper;
    _jc_javax_swing_InputMap$sub_refs	javax_swing_InputMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_InputMap$sub_nonrefs	javax_swing_InputMap;
    _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_nonrefs	javax_swing_text_JTextComponent__24KeymapWrapper;
};

// Object instance structure
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object {
	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtype	*vtype;
	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtype _jc_javax_swing_text_JTextComponent__24KeymapWrapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_JTextComponent__24KeymapWrapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_JTextComponent__24KeymapWrapper$class_object;

#endif	/* _JC_javax_swing_text_JTextComponent__24KeymapWrapper_H_ */

==> jc-1.4.5.tar.gz: javax/swing/text/JTextComponent__24KeymapWrapper.h <==
// class javax.swing.text.JTextComponent$KeymapWrapper

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 790c4e1b642750d1 javax_swing_InputMap
// @dep_class 9c12f8e28e5102dd javax_swing_text_JTextComponent__24KeymapWrapper

// header file dependencies
// @dep_header javax_swing_InputMap

#include "javax/swing/InputMap.h"

#ifndef _JC_javax_swing_text_JTextComponent__24KeymapWrapper_H_
#define _JC_javax_swing_text_JTextComponent__24KeymapWrapper_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_javax_swing_KeyStroke$object;
struct _jc_javax_swing_text_JTextComponent$object;
struct _jc_javax_swing_text_Keymap$object;

// Typedefs
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_refs	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_nonrefs	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$refs	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$refs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$nonrefs	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$nonrefs;
typedef struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$object;

typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vmethods	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vmethods;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtable	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtable;
typedef const struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtype	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtype;

// Constructors
extern void _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method$_init$7c9889f92e4657d3(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *, struct _jc_javax_swing_text_JTextComponent$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_javax_swing_text_JTextComponent__24KeymapWrapper$method$allKeys$fca17f47510e13bb(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_javax_swing_text_JTextComponent__24KeymapWrapper$method$get$191a2e1929297667(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *, struct _jc_javax_swing_KeyStroke$object *) _JC_JCNI_ATTR;
extern _jc_object_array *_jc_javax_swing_text_JTextComponent__24KeymapWrapper$method$keys$aa8bd082cd0ed021(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method$size$345df5220fc60ade(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method_info$allKeys$fca17f47510e13bb;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method_info$get$191a2e1929297667;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method_info$keys$aa8bd082cd0ed021;
extern _jc_method _jc_javax_swing_text_JTextComponent__24KeymapWrapper$method_info$size$345df5220fc60ade;

// Virtual methods structure
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vmethods {
	_jc_object_array	*(*allKeys$fca17f47510e13bb)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*get$191a2e1929297667)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *, struct _jc_javax_swing_KeyStroke$object *) _JC_JCNI_ATTR;
	_jc_object_array	*(*keys$aa8bd082cd0ed021)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *) _JC_JCNI_ATTR;
	jint	(*size$345df5220fc60ade)(_jc_env *, struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_InputMap$vmethods	javax_swing_InputMap;
	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vmethods	javax_swing_text_JTextComponent__24KeymapWrapper;
};

// Vtype
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtype {
	_jc_type			type;
	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_refs {
	struct _jc_object	*map;
	struct _jc_javax_swing_text_JTextComponent$object	*this;
};

// Reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$refs {
    _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_refs	javax_swing_text_JTextComponent__24KeymapWrapper;
    _jc_javax_swing_InputMap$sub_refs	javax_swing_InputMap;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_InputMap$sub_nonrefs	javax_swing_InputMap;
    _jc_javax_swing_text_JTextComponent__24KeymapWrapper$sub_nonrefs	javax_swing_text_JTextComponent__24KeymapWrapper;
};

// Object instance structure
struct _jc_javax_swing_text_JTextComponent__24KeymapWrapper$object {
	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtype	*vtype;
	_jc_javax_swing_text_JTextComponent__24KeymapWrapper$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_text_JTextComponent__24KeymapWrapper$vtype _jc_javax_swing_text_JTextComponent__24KeymapWrapper$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_text_JTextComponent__24KeymapWrapper, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_text_JTextComponent__24KeymapWrapper$class_object;

#endif	/* _JC_javax_swing_text_JTextComponent__24KeymapWrapper_H_ */
